package chat

import (
	errmsg "confrontation-training/err"
	"confrontation-training/models"
	"confrontation-training/response"
	"confrontation-training/service"
	"fmt"
	"github.com/gin-gonic/gin"
)

type AnswerService struct {
	service.AnswerService
}

func GteAnswerService() *AnswerService {
	return &AnswerService{}
}

// CreateAnswer
// PingExample confrontation-training
// @Summary 录入答案
// @Schemes
// @Description 录入答案
// @Tags 问答管理
// @Param q body string true "questionNo:问题编号；NextQuestionNo：下一个问题编号；answer：答案"
// @Accept json
// @Produce json
// @Success 200 {string} string "ok"
// @Router /v1/chat/create/answer [post]
func (a *AnswerService) CreateAnswer(c *gin.Context) {
	var param models.CreateAnswer
	err := c.ShouldBindJSON(&param)
	if err != nil {
		panic(err)
		return
	}
	answer, count := a.CreateNewAnswer(param)
	if count == 0 {
		response.Failed(errmsg.AnswerCreateFailed, c)
	} else {
		response.Success(errmsg.CreateSuccess, answer, c)
	}
	return
}

//GetAnswer
// PingExample confrontation-training
// @Summary 查询答案
// @Schemes
// @Description 查询答案
// @Tags 问答管理
// @Param id query uint8 false "id:问题主键"
// @Accept json
// @Produce json
// @Success 200 {string} string "ok"
// @Router /v1/ chat/get/chat [get]
func (a *AnswerService) GetAnswer(c *gin.Context) {

	var id uint8
	err := c.ShouldBind(&id)
	questions, count := a.FindAnswerByQuestionId(id)
	if err != nil {
		fmt.Println("查询答案信息出错：" + err.Error())
		panic(err)
	}
	if count <= 0 {
		response.Failed(errmsg.FindAnswerFailed, c)
	} else {
		response.Success(errmsg.FindSuccess, questions, c)
	}
	return
}
